//
//	aegis - project change supervisor
//	Copyright (C) 2002-2005 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to manipulate complet_times
//

#include <libaegis/change/branch.h>
#include <common/error.h> // for assert
#include <common/now.h>


time_t
change_completion_timestamp(change_ty *cp)
{
    cstate_ty       *cstate_data;

    cstate_data = change_cstate_get(cp);
    if (!cp->bogus && cstate_data->state == cstate_state_completed)
    {
	cstate_history_ty *chp;
	cstate_history_list_ty *chlp;

	chlp = cstate_data->history;
	assert(chlp);
	assert(chlp->length);
	chp = chlp->list[chlp->length - 1];
	assert(chp);
	return chp->when;
    }
    return now();
}
